//Home script
'use strict';

let pseudo          = new Clock();
let rtc             = new Clock();

let pseudoDisplay   = false;
let pseudoStartMs   = 0;

let diffMs          = 0;

let rtcIsSet        = false;
let clockIsSet      = false;
let ppsStable       = false;
let nmeaStable      = false;
let rateIsLocked    = false;
let timeIsLocked    = false;

const DISPLAY_LEAP_MS = 10000;

function parse()
{
    let lines = Ajax.response.split('\n');
    rtc.ms          = Ajax.date.getTime();
    rtc.ms         += parseInt(lines[0], 16);
    rtc.ms         -= Ajax.ms;
    diffMs          = rtc.ms + Ajax.ms - Date.now();
    rtcIsSet        = Ajax.hexToBit(lines[1], 0);
    clockIsSet      = Ajax.hexToBit(lines[1], 1);
    ppsStable       = Ajax.hexToBit(lines[1], 2);
    nmeaStable      = Ajax.hexToBit(lines[1], 3);
    rateIsLocked    = Ajax.hexToBit(lines[1], 4);
    timeIsLocked    = Ajax.hexToBit(lines[1], 5);
    rtc.leapEnable  = Ajax.hexToBit(lines[1], 6);
    rtc.leapForward = Ajax.hexToBit(lines[1], 7);
    rtc.months1970  = parseInt(lines[2], 16);
    rtc.leaps       = parseInt(lines[3], 16);
}
function display()
{
    let elem;
    elem = Ajax.getElementOrNull('ajax-rtc-set'      ); if (elem) elem.setAttribute('dir', rtcIsSet     ? 'rtl' : 'ltr');
    elem = Ajax.getElementOrNull('ajax-clock-set'    ); if (elem) elem.setAttribute('dir', clockIsSet   ? 'rtl' : 'ltr');
    elem = Ajax.getElementOrNull('ajax-pps-stable'   ); if (elem) elem.setAttribute('dir', ppsStable    ? 'rtl' : 'ltr');
    elem = Ajax.getElementOrNull('ajax-nmea-stable'  ); if (elem) elem.setAttribute('dir', nmeaStable   ? 'rtl' : 'ltr');
    elem = Ajax.getElementOrNull('ajax-rate-locked'  ); if (elem) elem.setAttribute('dir', rateIsLocked ? 'rtl' : 'ltr');
    elem = Ajax.getElementOrNull('ajax-time-locked'  ); if (elem) elem.setAttribute('dir', timeIsLocked ? 'rtl' : 'ltr');
    
    elem = Ajax.getElementOrNull('ajax-leap-enable'  ); if (elem) elem.setAttribute('dir', rtc.leapEnable   ? 'rtl' : 'ltr');
    elem = Ajax.getElementOrNull('ajax-leap-forward' ); if (elem) elem.setAttribute('dir', rtc.leapForward  ? 'rtl' : 'ltr');
    
    elem = Ajax.getElementOrNull('ajax-leap-year'    ); if (elem) elem.value = rtc.months1970 ? rtc.leapYear  : '';
    elem = Ajax.getElementOrNull('ajax-leap-month'   ); if (elem) elem.value = rtc.months1970 ? rtc.leapMonth : '';
    
    elem = Ajax.getElementOrNull('ajax-leap-count'   ); if (elem) elem.value = rtc.leaps;
    
    elem = Ajax.getElementOrNull('ajax-date-diff'    ); if (elem) elem.textContent = diffMs;
}

function handleTick() //This typically called every 100ms
{
    if (pseudoDisplay)
    {
        pseudo.adjustLeap (Ajax.ms);
        pseudo.displayTime(Ajax.ms);
        if (Ajax.ms >= pseudoStartMs + DISPLAY_LEAP_MS + 500) pseudoDisplay = false;
    }
    else
    {
        rtc.adjustLeap (Ajax.ms);
        rtc.displayTime(Ajax.ms);
    }
}

function displayLeap() //Called by display leap button in HTML
{
   pseudoDisplay = true;
   pseudoStartMs = Ajax.ms;
   
   pseudo.leapEnable  = true;
   pseudo.leapForward = rtc.leapForward;
   pseudo.leaps       = rtc.leaps;
   pseudo.leapMonth   = rtc.leapMonth;
   pseudo.leapYear    = rtc.leapYear;
   pseudo.ms          = Date.UTC(rtc.leapYear, rtc.leapMonth - 1, 1) - DISPLAY_LEAP_MS / 2 - Ajax.ms;
}
Ajax.server     = '/home-ajax';
Ajax.onResponse = function() { parse(); display(); };
Ajax.onTick     = handleTick;
Ajax.init();

